@@ -4,6 +4,7 @@ from pathlib import Path
 from typing import Optional, Union
 
 import jinja2
+import requests
 import yaml
 from huggingface_hub import hf_hub_download, upload_file
 from huggingface_hub.utils.logging import get_logger
@@ -104,12 +105,52 @@ class RepoCard:
 
         return cls(Path(card_path).read_text())
 
-    def push_to_hub(self, repo_id, repo_type=None):
+    def validate(self, repo_type="model"):
+        """Validates card against Hugging Face Hub's model card validation logic.
+        Using this function requires access to the internet, so it is only called
+        internally by `modelcards.ModelCard.push_to_hub`.
+
+        Args:
+            repo_type (str, *optional*):
+                The type of Hugging Face repo to push to. Defaults to None, which will use
+                use "model". Other options are "dataset" and "space".
+        """
+        if repo_type is None:
+            repo_type = "model"
+
+        # TODO - compare against repo types constant in huggingface_hub if we move this object there.
+        if repo_type not in ["model", "space", "dataset"]:
+            raise RuntimeError(
+                "Provided repo_type '{repo_type}' should be one of ['model', 'space',"
+                " 'dataset']."
+            )
+
+        body = {
+            "repoType": repo_type,
+            "content": str(self),
+        }
+        headers = {"Accept": "text/plain"}
+
+        try:
+            r = requests.post(
+                "https://huggingface.co/validate-yaml", body, headers=headers
+            )
+            r.raise_for_status()
+        except requests.exceptions.HTTPError as exc:
+            if r.status_code == 400:
+                raise RuntimeError(r.text)
+            else:
+                raise exc
+
+    def push_to_hub(self, repo_id, token=None, repo_type=None):
         """Push a RepoCard to a Hugging Face Hub repo.
 
         Args:
             repo_id (str):
                 The repo ID of the Hugging Face Hub repo to push to. Example: "nateraw/food".
+            token (str, *optional*):
+                Authentication token, obtained with `huggingface_hub.HfApi.login` method. Will default to
+                the stored token.
             repo_type (str, *optional*):
                 The type of Hugging Face repo to push to. Defaults to None, which will use
                 use "model". Other options are "dataset" and "space".
@@ -123,6 +164,9 @@ class RepoCard:
             )
             self.data.model_name = repo_name
 
+        # Validate card before pushing to hub
+        self.validate(repo_type=repo_type)
+
         with tempfile.TemporaryDirectory() as tmpdir:
             tmp_path = Path(tmpdir) / "README.md"
             tmp_path.write_text(str(self))
@@ -130,6 +174,7 @@ class RepoCard:
                 path_or_fileobj=str(tmp_path),
                 path_in_repo="README.md",
                 repo_id=repo_id,
+                token=token,
                 repo_type=repo_type,
                 identical_ok=True,
             )
